@@ -23,7 +23,7 @@ class SimplePriorityQueue(list):
         )
 
     def __iter__(self):
-        for _ in range(len(self)):
+        while True:
             yield self.pop_pri()
 
     def append(self, obj: Any) -> None:
@@ -51,7 +51,7 @@ if __name__ == '__main__':
     queue = SimplePriorityQueue()
 
     for i in range(100):
-        queue.push_pri('*' * i, randint(1, 100))
+        queue.push_pri('*' * i, randint(1, 1000))
 
     print(queue)
     [print(i) for i in queue]
